# YouDao Console Version

Simple wrapper for Youdao online translate (Chinese <-> English) service [API](http://fanyi.youdao.com/openapi?path=data-mode), as an alternative to the StarDict Console Version(sdcv).

## Environment:
 * Python ( >=2.7, 3.x ) 